@@ -12,7 +12,7 @@ use warnings;
 
 package App::Magpie::App::Command;
 BEGIN {
-  $App::Magpie::App::Command::VERSION = '1.110570';
+  $App::Magpie::App::Command::VERSION = '1.110680';
 }
 # ABSTRACT: base class for sub-commands
 
@@ -21,6 +21,7 @@ use Moose;
 use MooseX::Has::Sugar;
 
 use App::Magpie;
+use App::Magpie::Logger;
 
 
 # -- public attributes
@@ -38,17 +39,21 @@ has magpie => (
 
 sub log_init {
     my ($self, $opts) = @_;
-    $self->magpie->logger->set_muted(1) if $opts->{quiet};
-    $self->magpie->logger->set_debug(1) if $opts->{verbose};
+
+    my $logger =App::Magpie::Logger->instance;
+    $logger->more_verbose for 0 .. $opts->{verbose};
+    $logger->less_verbose for 0 .. $opts->{quiet};
 }
 
 
 
 sub verbose_options {
+    my $logger    = App::Magpie::Logger->instance;
+    my $log_level = ( qw{ quiet normal debug } )[ $logger->log_level ];
     return (
-        [ "Logging options" ],
-        [ 'verbose|v' => "display extra information" ],
-        [ 'quiet|q'   => "be quiet unless error"     ],
+        [ "Logging options (default log level: $log_level)" ],
+        [ 'verbose|v+' => "be more verbose (can be repeated)",  {default=>0} ],
+        [ 'quiet|q+'   => "be less versbose (can be repeated)", {default=>0} ],
     );
 }
 
@@ -63,7 +68,7 @@ App::Magpie::App::Command - base class for sub-commands
 
 =head1 VERSION
 
-version 1.110570
+version 1.110680
 
 =head1 DESCRIPTION
 
